#!/bin/bash

# $1 - path to pts folder
# $2 - configuration file name (without extension)

 echo "################################################################################" | tee resp.txt

if [[ $1 == 'h' ]] ;then
  echo "$1 - path to pts folder" | tee -a resp.txt
  echo "$2 - configuration file name (without extension)" | tee -a resp.txt
  exit 113 # just showing help
fi

echo "################################################################################" | tee -a resp.txt

echo "Finding FTRN ttyUSBx" | tee -a resp.txt
TTY_USB=`$1/utils/find_ftrn_ttyUSB.sh`
if [[ -n $TTY_USB ]]; then
  echo "Found FTRN ttyUSB : $TTY_USB" | tee -a resp.txt
else	
  echo "No FTRN ttyUSB device present. Check if Cypress microcontroller is programmed!" | tee -a resp.txt
  echo "PTS_STATUS: Failed" | tee -a resp.txt
  exit 64
fi

echo "Burning rpd to FLASH" | tee -a resp.txt
#RESP=`eb-flash "dev/$TTY_USB" "$2.rpd"`
#TEST=`echo $RESP | grep "Verifying"`
#TEST=`echo $TEST | grep "done"`

eb-flash "dev/$TTY_USB" "$2.rpd" | tee -a resp.txt

RESP=$(cat resp.txt)
TEST=`echo $RESP | grep "Verifying"`
TEST=`echo $TEST | grep "done"`


if [[ -z $TEST ]]; then
  echo "Verify not ok. Loading FPGA flash failed." | tee -a resp.txt
  echo "PTS_STATUS: Failed" | tee -a resp.txt
  exit 64
else
  echo "PTS_OK: Successfully burned FPGA flash." | tee -a resp.txt
fi
sleep 1

echo "Reseting FTRN. Loading FPGA from flash" | tee -a resp.txt
eb-reset "dev/$TTY_USB" | tee -a resp.txt
sleep 3

echo "Checking USB communication" | tee -a resp.txt
#RESP=`eb-info dev/$TTY_USB`
eb-info dev/$TTY_USB | tee -a resp.txt
RESP=$(cat resp.txt)
TEST=`echo $RESP | grep "5agxma3d4f27i3"`

if [[ -z $TEST ]]; then
  echo "FPGA loading from flash failed. Could not read GW info." | tee -a resp.txt
  echo "PTS_STATUS: Failed" | tee -a resp.txt
  exit 64
else
  echo "Successfully loaded FPGA from flash." | tee -a resp.txt
  echo "PTS_STATUS: OK" | tee -a resp.txt
  exit 0
fi

