#!/bin/bash

# $1 - path to pts folder
# $2 - configuration file name

echo "################################################################################" | tee resp.txt
if [[ $1 == 'h' ]];then
  echo "$1 - path to pts folder" | tee -a resp.txt
  echo "$2 - configuration file name" | tee -a resp.txt
  exit 113 # just showing help
fi

if [[ -z $2 ]]; then
  SOFNAME="./microtca_control.sof"
else
  SOFNAME="$2"
fi

echo "Check that Altera USB Blaster is connected to front panel JTAG connector" | tee -a resp.txt
echo " and DIP1 is in position  ONU(USB) then press ENTER" | tee -a resp.txt
read -s -n 1 

echo "Flashing FPGA" | tee -a resp.txt

export PATH=$PATH:/home/ftrn/intelFPGA/17.1/qprogrammer/bin:/home/ftrn/intelFPGA/17.1/qprogrammer/linux64/

echo "Detecting devices in JTAG chain" | tee -a resp.txt
jtagconfig | tee -a resp.txt

RESP=`cat resp.txt | grep "chain broken"`
if [[ -n $RESP ]]; then
  echo "No Altera Device found in JTAG chain"
  echo "PTS_STATUS: Failed"
  exit 64
fi

echo "Loading SOF to FPGA" | tee -a resp.txt
quartus_pgm -c "USB-Blaster" -m jtag -o "p;$SOFNAME@2"  | tee -a resp.txt
sleep 2
echo "Done programming sof" | tee -a resp.txt
sleep 2

echo "Checking for Cypress device" | tee -a resp.txt
CYPRESS=$(lsusb | grep "Cypress") | tee -a resp.txt

echo "Checking for OpenMoko device" | tee -a resp.txt
OPENMOKO=$(lsusb | grep "1d50:6062 OpenMoko")  | tee -a resp.txt

if [[ -n $CYPRESS ]] && [[ -n $OPENMOKO ]]; then
  echo "PTS_STATUS: Failed . FPGA flashed but Cypress not visible on USB bus." | tee -a resp.txt
  exit 64
elif [[ -n $CYPRESS ]]; then
  echo "FPGA loaded, Cypress visible on USB bus. Now flash Cypress microcontroller." | tee -a resp.txt
  echo "PTS_STATUS: OK"   | tee -a resp.txt
  exit 0
else #
  echo "FPGA loaded, OpenMoko visible on USB bus. Configure FPGA flash." | tee -a resp.txt
  echo "PTS_STATUS: OK" | tee -a resp.txt
  exit 0
fi

