#!/bin/bash

# $1 - FTRN Saflib name

FTRN=$1

saft-io-ctl $1 -i | grep MTCA4

echo "Enabling SW controlled HW tests"
saft-io-ctl $FTRN -n HWT_EN -d 1


echo "Enabling MTCA.4 MLVDS buffers" | tee resp.txt
saft-io-ctl $FTRN -n LED_USR5 -d 0
saft-io-ctl $FTRN -n LED_USR7 -d 1
sleep 0.5

echo "Turning all MTCA4 MLVDS outputs off" | tee resp.txt
for ((i=1; i<=8; i++))
do
  saft-io-ctl $1 -n "MTCA4_IO$i" -d 0 -o 0
done

echo "Reading back MTCA4 MLVDS inputs" | tee resp.txt
for ((i=1; i<=8; i++))
do
  saft-io-ctl $1 -n "MTCA4_IO$i"
done

echo " "

echo "Enabling Libera buffers" | tee resp.txt
saft-io-ctl $FTRN -n LED_USR5 -d 0
saft-io-ctl $FTRN -n LED_USR6 -d 1
sleep 0.5


echo "Driving Libera lines and reading them back on MTCA.4 MLVDS lines" | tee -a resp.txt
for ((i=1; i<=4; i++))
do
  let j=i*2-1
  let k=i*2

  echo "--------------------------------------------------------" | tee -a resp.txt
  echo "LIBERA_TR$i drive LO" | tee -a resp.txt
  saft-io-ctl $1 -n "LIBERA_TR$i" -d 0
  echo "Reding back MTCA4_IO$j and MTCA4_IO$k:" | tee -a resp.txt

    RESP=`saft-io-ctl $1 -n "MTCA4_IO$j" | grep "Input:"`
    echo "    IO$j : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "Low"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input $j" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi

    RESP=`saft-io-ctl $1 -n "MTCA4_IO$k" | grep "Input:"`
    echo "    IO$k : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "Low"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input $k" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi

  sleep 0.5 

  echo "--------------------------------------------------------" | tee -a resp.txt
  echo "LIBERA_TR$i drive HI" | tee -a resp.txt
  saft-io-ctl $1 -n "LIBERA_TR$i" -d 1
  echo "Reding back MTCA4_IO$j and MTCA4_IO$k:" | tee -a resp.txt
    RESP=`saft-io-ctl $1 -n "MTCA4_IO$j" | grep "Input:"`
    echo "    IO$j : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "High"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input $j" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi

    RESP=`saft-io-ctl $1 -n "MTCA4_IO$k" | grep "Input:"`
    echo "    IO$k : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "High"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input $k" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi


  
  sleep 1

  saft-io-ctl $1 -n "LIBERA_TR$i" -d 0

done


echo "Disabling Libera buffers" | tee -a resp.txt
saft-io-ctl $1 -n LED_USR5 -d 0
saft-io-ctl $1 -n LED_USR6 -d 0
saft-io-ctl $1 -n LED_USR7 -d 0
saft-io-ctl $1 -n HWT_EN -d 0


echo "Test finished!" | tee -a resp.txt
echo "PTS_STATUS: OK" | tee -a resp.txt
