#!/bin/bash

# $1 - FTRN Saflib name

CLK_1=(1 2 3 4)
CLK_2=(2 1 4 3)

saft-io-ctl $1 -i | grep MTCA4

echo "Enabling MTCA.4 buffers" | tee resp.txt
saft-io-ctl $1 -n LED_USR5 -d 0
saft-io-ctl $1 -n LED_USR6 -d 1
saft-io-ctl $1 -n LED_USR7 -d 1
saft-io-ctl $1 -n HWT_EN -d 1

echo "Turning all MTCA4 CLK lines off" | tee -a resp.txt
for ((i=1; i<=4; i++))
do
  saft-io-ctl $1 -n "MTCA4_CLK$i" -d 0 -o 0
done

echo "Reading MTCA4 CLK lines" | tee -a resp.txt
for ((i=1; i<=4; i++))
do
  saft-io-ctl $1 -n "MTCA4_CLK$i" | grep Input
done

#echo "Driving MTCA4 CLK line"
for ((i=0; i<${#CLK_1[@]}; i++))
do
  
  echo "---------------------------------------------------------" | tee -a resp.txt
  echo "Testing MTCA.4 ${CLK_1[i]}-${CLK_2[i]} CLK pair" | tee -a resp.txt
  echo ""
  echo "MTCA4_CLK${CLK_1[i]} as output: drive LO" | tee -a resp.txt

  saft-io-ctl $1 -n "MTCA4_CLK${CLK_1[i]}" -o 1 -d 0
  saft-io-ctl $1 -n "MTCA4_CLK${CLK_1[i]}" | grep Output

  printf "Reading back MTCA4_CLK%d : " "${CLK_2[i]}" | tee -a resp.txt

  RESP=`saft-io-ctl $1 -n "MTCA4_CLK${CLK_2[i]}" | grep "Input:"`

  echo "$RESP" | tee -a resp.txt
  IOSTATE=`echo "$RESP" | grep "Low"`
  if [[ -z $IOSTATE ]];then
	echo "Invalid state on input MTCA4_CLK${CLK_2[i]}" | tee -a resp.txt
	echo "PTS_STATUS: Failed" | tee -a resp.txt
	exit
  fi  
  
  sleep 0.5

  echo "--------------------------------------------------------" | tee -a resp.txt
  echo "MTCA4_CLK${CLK_1[i]} as output: drive HI" | tee -a resp.txt

  saft-io-ctl $1 -n "MTCA4_CLK${CLK_1[i]}" -o 1 -d 1
  saft-io-ctl $1 -n "MTCA4_CLK${CLK_1[i]}" | grep Output

  printf "Reading back MTCA4_CLK%d : " "${CLK_2[i]}" | tee -a resp.txt

  RESP=`saft-io-ctl $1 -n "MTCA4_CLK${CLK_2[i]}" | grep Input`

  echo "$RESP" | tee -a resp.txt

  IOSTATE=`echo "$RESP" | grep "High"`
  if [[ -z $IOSTATE ]];then
	echo "Invalid state on input MTCA4_CLK${CLK_2[i]}" | tee -a resp.txt
	echo "PTS_STATUS: Failed" | tee -a resp.txt
	exit
  fi  
  
  sleep 0.1  
  saft-io-ctl $1 -n "MTCA4_CLK${CLK_1[i]}" -o 0 -d 0
  sleep 1
done

echo "Disabling MTCA.4 buffers" | tee -a resp.txt
saft-io-ctl $1 -n LED_USR5 -d 0
saft-io-ctl $1 -n LED_USR6 -d 0
saft-io-ctl $1 -n LED_USR7 -d 0
saft-io-ctl $1 -n HWT_EN -d 0


echo "Test finished. IO voltage levels are OK" | tee -a resp.txt
echo "PTS_STATUS: OK" | tee -a  resp.txt  

