#!/bin/bash

# $1 - FTRN Saflib name


saft-io-ctl $1 -i | grep MTCA4

echo "Enabling MTCA.4 buffers" | tee resp.txt
saft-io-ctl $1 -n LED_USR5 -d 0
saft-io-ctl $1 -n LED_USR6 -d 1
saft-io-ctl $1 -n LED_USR7 -d 1
saft-io-ctl $1 -n HWT_EN -d 1


echo "Turning all MTCA4 MLVDS lines off" | tee -a resp.txt
for ((i=1; i<=8; i++))
do
  saft-io-ctl $1 -n "MTCA4_IO$i" -d 0
done

echo "Reading MTCA4 lines" | tee -a resp.txt
for ((i=1; i<=8; i++))
do
  saft-io-ctl $1 -n "MTCA4_IO$i" | grep Input
done

echo "Testing IOs. One IO as output, others as intpus." | tee -a resp.txt
for ((i=1; i<=8; i++))
do
  echo "--$i-----------------------------------------------------" | tee -a resp.txt
  echo "MTCA4_IO$i as output: drive LO" | tee -a resp.txt
  saft-io-ctl $1 -n "MTCA4_IO$i" -o 1 -d 0
  saft-io-ctl $1 -n "MTCA4_IO$i" | grep Output
  echo "--------------------------------------------------------" | tee -a resp.txt

  for ((j=1; j<=8; j++))
  do

    RESP=`saft-io-ctl $1 -n "MTCA4_IO$j" | grep "Input:"`
    echo "    IO$j : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "Low"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input $j" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi
  done

  echo "--------------------------------------------------------" | tee -a resp.txt
  echo "MTCA4_IO$i as output: drive HI" | tee -a resp.txt
  saft-io-ctl $1 -n "MTCA4_IO$i" -o 1 -d 1
  saft-io-ctl $1 -n "MTCA4_IO$i" | grep Output | tee -a resp.txt
  echo "--------------------------------------------------------" | tee -a resp.txt


  for ((j=1; j<=8; j++))
  do

    RESP=`saft-io-ctl $1 -n "MTCA4_IO$j" | grep "Input:"`
    echo "    IO$j : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "High"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input $j" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      sleep 1
      exit
    fi
  done

  saft-io-ctl $1 -n "MTCA4_IO$i" -o 0 -d 0
  
  sleep 1
done

echo "Reading MTCA4 lines" | tee -a resp.txt
for ((i=1; i<=8; i++))
do
  saft-io-ctl $1 -n "MTCA4_IO$i" | grep Input
done


echo "--------------------------------------------------------" | tee -a resp.txt
echo "Disabling MTCA.4 buffers"
saft-io-ctl $1 -n LED_USR5 -d 0
saft-io-ctl $1 -n LED_USR6 -d 0
saft-io-ctl $1 -n LED_USR7 -d 0
saft-io-ctl $1 -n HWT_EN -d 0


echo "Test finished. IO voltage levels are OK" | tee -a resp.txt
echo "PTS_STATUS: OK" | tee -a  resp.txt  
