#!/bin/bash

# $1 - FTRN Saflib name

IO_1=(1 2 3 4 5 6 7 8) 
IO_2=(2 1 4 3 6 5 8 7)

saft-io-ctl $1 -i | grep MTCA4

echo "Front panel IO LEDs showing MTCA.4 IO 1-4 state"
saft-io-ctl $1 -n LED_USR1 -d 0
saft-io-ctl $1 -n LED_USR2 -d 1
saft-io-ctl $1 -n LED_USR3 -d 1
saft-io-ctl $1 -n LED_USR4 -d 0

echo "Enabling MTCA.4 buffers" | tee resp.txt
saft-io-ctl $1 -n LED_USR5 -d 0
saft-io-ctl $1 -n LED_USR6 -d 0
saft-io-ctl $1 -n LED_USR7 -d 1
saft-io-ctl $1 -n HWT_EN -d 1


echo "Turning all MTCA4 MLVDS lines off" | tee -a resp.txt
for ((i=1; i<=8; i++))
do
  saft-io-ctl $1 -n "MTCA4_IO$i" -d 0 -o 0
done

echo "Reading MTCA4 lines" | tee -a resp.txt
for ((i=1; i<=8; i++))
do
  saft-io-ctl $1 -n "MTCA4_IO$i" | grep Input
done

echo "Testing MTCA.4 MLVDS IOs in pairs. One IO as output, other as intput." | tee -a resp.txt
for ((i=0; i<8; i++))
do

  if [[ $i == 4 ]];then
    echo "Front panel IO LEDs showing MTCA.4 IO 5-8 state"
    saft-io-ctl $1 -n LED_USR1 -d 1
    saft-io-ctl $1 -n LED_USR2 -d 1
    saft-io-ctl $1 -n LED_USR3 -d 1
    saft-io-ctl $1 -n LED_USR4 -d 0
  fi

  echo "---------------------------------------------------------" | tee -a resp.txt
  echo "MTCA4_IO${IO_1[i]} as output: drive LO" | tee -a resp.txt
  saft-io-ctl $1 -n "MTCA4_IO${IO_1[i]}" -o 1 -d 0
  saft-io-ctl $1 -n "MTCA4_IO${IO_1[i]}" | grep Output
  echo " " | tee -a resp.txt

    RESP=`saft-io-ctl $1 -n "MTCA4_IO${IO_1[i]}" | grep "Input:"`
    echo "    IO${IO_1[i]} : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "Low"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input ${IO_1[i]}" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi

    RESP=`saft-io-ctl $1 -n "MTCA4_IO${IO_2[i]}" | grep "Input:"`
    echo "    IO${IO_2[i]} : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "Low"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input ${IO_2[i]}" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi
  

  echo "--------------------------------------------------------" | tee -a resp.txt
  echo "MTCA4_IO${IO_1[i]} as output: drive HI" | tee -a resp.txt
  saft-io-ctl $1 -n "MTCA4_IO${IO_1[i]}" -o 1 -d 1
  saft-io-ctl $1 -n "MTCA4_IO${IO_1[i]}" | grep Output | tee -a resp.txt
  echo " " | tee -a resp.txt


    RESP=`saft-io-ctl $1 -n "MTCA4_IO${IO_1[i]}" | grep "Input:"`
    echo "    IO${IO_1[i]} : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "High"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input ${IO_1[i]}" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi

    RESP=`saft-io-ctl $1 -n "MTCA4_IO${IO_2[i]}" | grep "Input:"`
    echo "    IO${IO_2[i]} : $RESP" | tee -a resp.txt
    IOSTATE=`echo "$RESP" | grep "High"`
    if [[ -z $IOSTATE ]];then
      echo "Invalid state on input ${IO_2[i]}" | tee -a resp.txt
      echo "PTS_STATUS: Failed" | tee -a resp.txt
      exit
    fi

  saft-io-ctl $1 -n "MTCA4_IO${IO_1[i]}" -o 0 -d 0

  echo " "

  sleep 0.5
done

echo " "
echo "Reading MTCA4 lines" | tee -a resp.txt
for ((i=1; i<=8; i++))
do
  saft-io-ctl $1 -n "MTCA4_IO$i" | grep "Input:"  | tee -a resp.txt
done


echo "--------------------------------------------------------" | tee -a resp.txt
echo "Disabling MTCA.4 buffers"
saft-io-ctl $1 -n LED_USR5 -d 0
saft-io-ctl $1 -n LED_USR6 -d 0
saft-io-ctl $1 -n LED_USR7 -d 0
saft-io-ctl $1 -n HWT_EN -d 0

saft-io-ctl $1 -n LED_USR1 -d 0
saft-io-ctl $1 -n LED_USR2 -d 0
saft-io-ctl $1 -n LED_USR3 -d 0
saft-io-ctl $1 -n LED_USR4 -d 0

echo "Test finished. IO voltage levels are OK" | tee -a resp.txt
echo "PTS_STATUS: OK" | tee -a  resp.txt  
