#!/bin/bash

DLM1='################################################################################'
DLM2='--------------------------------------------------------------------------------'

echo $DLM1 | tee resp.txt
echo "Check that FTRN MMC and MCH are connected to PC. Press ENTER" | tee -a resp.txt
read -s -n 1

if [ -z $1 ]; then
  echo "arg1 : valid path to PTS folder"
  exit 113
fi

MMC_TTY=`$1/utils/find_ftrn_mmc_ttyUSB.sh`
MCH_TTY=`$1/utils/find_mch_ttyACM.sh`

if [[ -n $MMC_TTY ]]; then
  echo "Found MMC serial port: $MMC_TTY" | tee -a resp.txt
else
  echo "MMC serial port not available!" | tee -a resp.txt
  echo "PTS_STATUS: Failed" | tee -a resp.txt
  exit 64
fi 

if [[ -n $MCH_TTY ]]; then
  echo "Found MCH serial port: $MCH_TTY" | tee -a resp.txt
else
  echo "MCH serial port not available!" | tee -a resp.txt
  echo "PTS_STATUS: Failed" | tee -a resp.txt
  exit 65
fi 

echo $DML2 | tee -a resp.txt
echo "Connecting to MMC console" | tee -a resp.txt
stty -F /dev/$MMC_TTY 115200 raw -echo   #CONFIGURE SERIAL PORT
exec 3</dev/$MMC_TTY                     #REDIRECT SERIAL OUTPUT TO FD 3
cat <&3 > ./ttyMMCdump.log &          #REDIRECT SERIAL OUTPUT TO FILE
MMCPID=$!                                #SAVE PID TO KILL CAT

echo "Connecting to MCH console" | tee -a resp.txt
stty -F /dev/$MCH_TTY 115200 raw -echo   #CONFIGURE SERIAL PORT
exec 4</dev/$MCH_TTY                     #REDIRECT SERIAL OUTPUT TO FD 4
cat <&4 > ./ttyMCHdump.log &          #REDIRECT SERIAL OUTPUT TO FILE
MCHPID=$!                                #SAVE PID TO KILL CAT

echo "Pull out FTRN HotSwap handle and insert FTRN into crate. Press ENTER" | tee -a resp.txt
read -s -n 1

echo "MMC: raising debug report level"| tee -a resp.txt
echo "4" > /dev/$MMC_TTY             #SEND COMMAND STRING TO SERIAL PORT
sleep 1s                          #WAIT FOR RESPONSE

echo "MCH: showing FTRN fru info"| tee -a resp.txt
printf "\r\n\r\n" > /dev/$MCH_TTY             #SEND COMMAND STRING TO SERIAL PORT
sleep 1s                          #WAIT FOR RESPONSE
printf "show_fruinfo 6\r\n" > /dev/$MCH_TTY             #SEND COMMAND STRING TO SERIAL PORT
sleep 1s                          #WAIT FOR RESPONSE

echo "Push in FTRN HotSwap handle and wait until BLUE LED turns OFF. Press ENTER" | tee -a resp.txt
read -s -n 1

echo "Shutting down and restarting FTRN FRU via ipmi"
echo "MCH: Shutting down FTRN FRU"| tee -a resp.txt
printf "shutdown 6\r\n" > /dev/$MCH_TTY             #SEND COMMAND STRING TO SERIAL PORT

echo "Press key when FTRN is off (BLUE LED is on)" | tee -a resp.txt                         #WAIT FOR RESPONSE
read -n 1 -s -t 15

echo "MCH: Starting FTRN FRU"
printf "fru_start 6\r\n" > /dev/$MCH_TTY             #SEND COMMAND STRING TO SERIAL PORT
echo "Press key when FTRN is ON (BLUE LED is OFF)" | tee -a resp.txt
read -n 1 -s -t 15

# force bus rescan
echo 1 > /sys/bus/pci/rescan


MMCRESP=`cat ./ttyMMCdump.log`	        #DUMP CAPTURED DATA
printf "\r\n\r\n%s\r\n MMC RESPONSE"  "$DLM1" | tee -a resp.txt                         #WAIT FOR RESPONSE
echo "$MMCRESP" | tee -a resp.txt
kill $MMCPID;                             #KILL CAT PROCESS
exec 3<&- ;                             #FREE FD 3

MCHRESP=`cat ./ttyMCHdump.log`	        #DUMP CAPTURED DATA
printf "\r\n\r\n%s\r\n MCH RESPONSE"  "$DLM1" | tee -a resp.txt                         #WAIT FOR RESPONSE
echo "$MCHRESP" | tee -a resp.txt
kill $MCHPID;                             #KILL CAT PROCESS
exec 4<&- ;                             #FREE FD 3

if [ -z "$MMCRESP" ]; then
  echo "No response from MMC. Could not read MMC build info" | tee -a resp.txt
  echo "PTS_STATUS: Failed" | tee -a resp.txt
  exit 66
fi

if [ -z "$MCHRESP" ]; then
  echo "No response from MCH" | tee -a resp.txt
  echo "PTS_STATUS: Failed" | tee -a resp.txt
  exit 67
else 
  echo "PTS_STATUS: OK" | tee -a resp.txt
  exit 0
fi
