#!/bin/bash

# $1 PTS path
# $2 command

PTS_PATH=$1
CMD=$2

echo "###################################################################" | tee resp.txt
echo "Killing Saftlib" | tee -a resp.txt
killall -9 saftd
sleep 0.5s

echo "Removing FTRN kernel modules" | tee -a resp.txt
rmmod pcie_wb
sleep 0.5s
rmmod wishbone-serial
sleep 0.5s
rmmod wishbone
sleep 0.5s

if [ "$CMD" == "r" ]; #just removing kernel modules
then
  echo "PTS_STATUS: OK" | tee -a resp.txt
  exit
fi

echo "-------------------------------------------------------------------" | tee -a resp.txt
echo "Checking that one FTRN device is visible on the PCI bus" | tee -a resp.txt
CHECK=`lspci | grep CERN`
echo $CHECK

if [[ -n $CHECK ]]; then
  echo "FTRN present on the PCI bus" | tee -a resp.txt
else
  echo "No FTRN present on the PCI bus" | tee -a resp.txt
  echo "PTS_STATUS: Failed (64)" | tee -a resp.txt
  exit
fi


echo "-------------------------------------------------------------------" | tee -a resp.txt
echo "Inserting Wishbone FTRN kernel modules" | tee -a resp.txt
insmod wishbone.ko
sleep 0.5s
insmod wishbone-serial.ko
sleep 0.5s

if [ "$CMD" != "w" ]; # if not inserting only wishbone
then
  echo "Inserting PCI FTRN kernel module" | tee -a resp.txt
  insmod pcie_wb.ko
fi

echo "-------------------------------------------------------------------" | tee -a resp.txt
echo "Checking FTRN kernel modules" | tee -a resp.txt
echo "" | tee -a resp.txt
lsmod | grep pcie_wb
lsmod | grep wishbone


echo "--Checking device handles-------------------------------------------" | tee -a resp.txt
ls -l /dev | grep wbm  | tee -a resp.txt
FTRN_TTY=`$PTS_PATH/utils/find_ftrn_ttyUSB.sh`
ls -l /dev | grep $FTRN_TTY | tee -a resp.txt

echo "--Checking assigned interrupts--------------------------------------" | tee -a resp.txt
cat /proc/interrupts | grep wb | tee -a resp.txt

echo "--Checking probe messages-------------------------------------------" | tee -a resp.txt
dmesg -c | grep pcie_wb | tee -a resp.txt

echo "-------------------------------------------------------------------" | tee -a resp.txt
echo "-- Checking GW version of wbm0 ------------------------------------" | tee -a resp.txt
echo "" | tee -a resp.txt
GW_WBM=`eb-info dev/wbm0`
echo "$GW_WBM" | tee -a resp.txt
echo "-------------------------------------------------------------------" | tee -a resp.txt
echo "-- Checking GW version of $FTRN_TTY--------------------------------" | tee -a resp.txt
echo "" | tee -a resp.txt
GW_TTY=`eb-info dev/$FTRN_TTY`
echo "$GW_TTY" | tee -a resp.txt

echo " " | tee -a resp.txt
echo " " | tee -a resp.txt
if [[ "$GW_TTY" == "$GW_WBM" ]]; then
  echo "Kernel modules inserted OK." | tee -a resp.txt
  echo "PTS_STATUS: OK" | tee -a resp.txt
  exit
else
  echo "Kernel modules not or GW info can not be read via PCI or USB." | tee -a resp.txt
  echo "PTS_STATUS: Failed" | tee -a resp.txt
  exit
fi
