#!/bin/bash

# $1 - test list
# $2 - serial and MAC list file
# $3 - UUT etherbone master

SN=$1
MAC=$2

MACS=`echo $MAC | tr ':' '-'` # for folder and file name

#echo "MAC  : $MAC"
#echo "MACS : $MACS"

#set paths
PTS=$(pwd)
#echo $PTS

export PATH=$PATH:/home/ftrn/intelFPGA/17.1/qprogrammer/bin:/home/ftrn/intelFPGA/17.1/qprogrammer/linux64/
TEST_LOG_DIR=/home/ftrn/Desktop/board_tests

TEST_DELIM1='###############################################################################';
TEST_DELIM2='-------------------------------------------------------------------------------';


RESP=`$PTS/uid/read_uid.sh $PTS;`
STATUS=$?
if [[ $STATUS != 0 ]]; then
  echo "Reading UID failed. Stopping!"
  exit
fi

#echo $RESP
#FTRNUID="12313"
FTRNUID=`printf "%s" "$RESP" | sed -n '5p'`

# assemble folder and file name	
LOG_NAME="amc"
LOG_NAME+="_sn-$SN"
LOG_NAME+="_uid-$FTRNUID"
LOG_NAME+="_mac-$MACS"

# echo "LOG_NAME : $LOG_NAME"
LOG_FOLDER="$TEST_LOG_DIR/$LOG_NAME"

if [[ -d $LOG_FOLDER ]];then
  rm $LOG_FOLDER/*
else
  mkdir $LOG_FOLDER
fi

LOG_FILE="$TEST_LOG_DIR/$LOG_NAME/$LOG_NAME.log"

#echo "log file name: $LOG_FILE"

# create log file
touch $LOG_FILE

date > $LOG_FILE
echo "SN   : $SN"      | tee -a $LOG_FILE
echo "UID  : $FTRNUID" | tee -a $LOG_FILE
echo "MAC  : $MAC"     | tee -a $LOG_FILE

# get UUT GW info
FTRN_TTY=`$PTS/utils/find_ftrn_ttyUSB.sh`
RESP=`eb-info dev/$FTRN_TTY`
GWINFO=`printf "%s" "$RESP" | sed -n '4p'` # gw branch
printf "%s\n" "$GWINFO" | tee -a $LOG_FILE
GWINFO=`printf "%s" "$RESP" | sed -n '12p'`
printf "\t%s\n\n" "$GWINFO" | tee -a $LOG_FILE # last commit comment

# log tools versions
printf "UUT GW:\n%s\n\n" "$RESP" > $LOG_FOLDER/environment_info.txt;
RESP=`eb-mon dev/$FTRN_TTY -e;`
printf "Etherbone:\n%s\n\n" "$RESP" >> $LOG_FOLDER/environment_info.txt;
RESP=`saft-ctl dummy -i;`
printf "Saflib:\n%s\n\n" "$RESP" >> $LOG_FOLDER/environment_info.txt;


#TESTS

#------------------------------------------------------------------------------
# WR link check
echo $TEST_DELIM2 
printf "WR link check : " | tee -a $LOG_FILE
RESP=`$PTS/wr/wr_check_link.sh pex $FTRN_TTY`
STATUS=$?
printf "%s\n" "$RESP" > $LOG_FOLDER/link_check.txt

if [[ $STATUS == 0 ]]; then
  printf "OK\n" | tee -a $LOG_FILE
else 
  printf "Failed ($STATUS)\n" | tee -a $LOG_FILE
  #exit
fi

#------------------------------------------------------------------------------
echo $TEST_DELIM2
printf "LED test : " | tee -a $LOG_FILE
RESP=`$PTS/leds/leds_all.sh amc`
STATUS=$?
printf "%s\n" "$RESP" > $LOG_FOLDER/leds_test.txt
if [[ $STATUS == 0 ]]; then
  printf "OK\n" | tee -a $LOG_FILE
else 
  printf "Failed ($STATUS)\n" | tee -a $LOG_FILE
  #exit	
fi
	
#------------------------------------------------------------------------------
echo $TEST_DELIM2
printf "MMC console test : " | tee -a $LOG_FILE
RESP=`$PTS/mmc_tty/mmc_console.sh $PTS`
STATUS=$?
printf "%s\n" "$RESP" > $LOG_FOLDER/mmc_console_test.txt
if [[ $STATUS == 0 ]]; then
  printf "OK\n" | tee -a $LOG_FILE
else 
  printf "Failed ($STATUS)\n" | tee -a $LOG_FILE
  #exit
fi

#------------------------------------------------------------------------------
echo $TEST_DELIM2
printf "MCH console test : " | tee -a $LOG_FILE
RESP=`$PTS/mch/mch_console.sh $PTS`
STATUS=$?
printf "%s\n" "$RESP" > $LOG_FOLDER/mch_console_test.txt
if [[ $STATUS == 0 ]]; then
  printf "OK\n" | tee -a $LOG_FILE
else 
  printf "Failed ($STATUS)\n" | tee -a $LOG_FILE
  #exit
fi

#------------------------------------------------------------------------------
echo $TEST_DELIM2
printf "MCH ipmitool test : " | tee -a $LOG_FILE
RESP=`$PTS/mch/mch_ipmitool.sh "10.68.5.141"`;
STATUS=$?
printf "%s\n" "$RESP" > $LOG_FOLDER/mch_ipmitool_test.txt
if [[ $STATUS == 0 ]]; then
  printf "OK\n" | tee -a $LOG_FILE
else 
  printf "Failed ($STATUS)\n" | tee -a $LOG_FILE
  #exit
fi

echo $TEST_DELIM1
echo "Done"

