#!/bin/bash

# $1 - path to flash tool folder and hex file

if [[ $1 == 'h' ]]
then
  echo "$1 - path to flash tool folder and hex file"
  exit 113 # just showing help
fi

if [[ -n $1 ]];then
  USB_CORE_DIR=$1
fi

CUR_DIR="$(pwd)"

echo "CUR_DIR : $CUR_DIR"

cd $USB_CORE_DIR

echo "################################################################################" | tee resp.txt
echo "Flashing USB Cypress microcontroller" | tee -a resp.txt
echo "Detecting Cypress CY7C68013 EZ-USB FX2 device on the USB bus" | tee -a resp.txt

lsusb

RESP_CYP=`lsusb | grep "CY7C68013 EZ-USB FX2"`
RESP_OMK=`lsusb | grep "OpenMoko"`

if [[ -n $RESP_CYP ]] || [[ -n $RESP_OMK ]]; then
  printf "Detected Cypress device : %s\n\n" "$RESP" | tee -a resp.txt
else
  printf "Cypress device not detected on the USB bus!\n" | -a tee resp.txt
  exit 64
fi

echo "Erasing Cypress flash" | tee -a resp.txt
./flash-fx2lp.sh -E
sleep 3
echo "Loading hex to Cypress flash" | tee -a resp.txt
./flash-fx2lp.sh
sleep 3
echo "Done loading Cypress flash" | tee -a resp.txt

cd $CUR_DIR

read -p "Power cycle the board for at least 10 sec. Then press ENTER" | tee -a resp.txt

echo "Checking if OpenMoko visible on usb bus" | tee -a resp.txt
RESP=`lsusb | grep "OpenMoko"`
if [[ -n $RESP ]]; then
  printf "Detected OpenMoko device : %s\n\n" "$RESP" | tee -a resp.txt
  echo "PTS_STATUS: OK" | tee -a resp.txt
  exit 0
else
  printf "PTS_STATUS: Failed. OpenMoko device not detected on the USB bus. Stopping.\n" | tee -a resp.txt
  exit 65
fi

